==> cxf-testutils-2.0.3.4-fuse-sources.jar: org/apache/type_test/xml/TestIDTypeAttribute.java <==

package org.apache.type_test.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types2.IDTypeAttribute;


/**
 * <p>Java class for testIDTypeAttribute element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testIDTypeAttribute">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="x" type="{http://apache.org/type_test/types2}IDTypeAttribute"/>
 *           &lt;element name="y" type="{http://apache.org/type_test/types2}IDTypeAttribute"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testIDTypeAttribute")
public class TestIDTypeAttribute {

    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected IDTypeAttribute x;
    @XmlElement(namespace = "http://apache.org/type_test/xml", required = true)
    protected IDTypeAttribute y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link IDTypeAttribute }
     *     
     */
    public IDTypeAttribute getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link IDTypeAttribute }
     *     
     */
    public void setX(IDTypeAttribute value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link IDTypeAttribute }
     *     
     */
    public IDTypeAttribute getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link IDTypeAttribute }
     *     
     */
    public void setY(IDTypeAttribute value) {
        this.y = value;
    }

}

==> cxf-testutils-2.1.3.3-fuse-sources.jar: org/apache/type_test/xml/TestIDTypeAttribute.java <==

package org.apache.type_test.xml;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types2.IDTypeAttribute;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="x" type="{http://apache.org/type_test/types2}IDTypeAttribute"/>
 *         &lt;element name="y" type="{http://apache.org/type_test/types2}IDTypeAttribute"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testIDTypeAttribute")
public class TestIDTypeAttribute {

    @XmlElement(required = true)
    protected IDTypeAttribute x;
    @XmlElement(required = true)
    protected IDTypeAttribute y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link IDTypeAttribute }
     *     
     */
    public IDTypeAttribute getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link IDTypeAttribute }
     *     
     */
    public void setX(IDTypeAttribute value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link IDTypeAttribute }
     *     
     */
    public IDTypeAttribute getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link IDTypeAttribute }
     *     
     */
    public void setY(IDTypeAttribute value) {
        this.y = value;
    }

}
